@@ -3,8 +3,8 @@ from typing import Optional
 
 from the_spymaster_solvers_client.structs.requests import LoadModelsRequest
 from the_spymaster_solvers_client.structs.responses import LoadModelsResponse
-from the_spymaster_util.http_client import DEFAULT_RETRY_STRATEGY, BaseHttpClient
-from the_spymaster_util.logging import wrap
+from the_spymaster_util.http.base_client import DEFAULT_RETRY_STRATEGY, BaseHttpClient
+from the_spymaster_util.logger import wrap
 from urllib3 import Retry
 
 from .structs import (
@@ -25,7 +25,7 @@ DEFAULT_BASE_URL = "http://localhost:8000"
 
 
 class TheSpymasterClient(BaseHttpClient):
-    def __init__(self, base_url: str = None, retry_strategy: Optional[Retry] = DEFAULT_RETRY_STRATEGY):
+    def __init__(self, base_url: Optional[str] = None, retry_strategy: Optional[Retry] = DEFAULT_RETRY_STRATEGY):
         if not base_url:
             base_url = DEFAULT_BASE_URL
         super().__init__(base_url=f"{base_url}/api/v1/game", retry_strategy=retry_strategy)
@@ -54,3 +54,6 @@ class TheSpymasterClient(BaseHttpClient):
     def load_models(self, request: LoadModelsRequest) -> LoadModelsResponse:
         data = self._post("load-models/", data=request.dict())
         return LoadModelsResponse(**data)
+
+    def raise_error(self, request: dict):
+        return self._get("raise-error/", data=request)
