@@ -1,12 +1,20 @@
-from typing import Any, Optional
+from typing import Any, Optional, Union
 
 from codenames.game import GameState, GivenGuess, GivenHint
 from pydantic import BaseModel, Extra
 from the_spymaster_solvers_client.structs.base import ModelIdentifier, Solver
 
 
-class BaseResponse(BaseModel):
+class HttpResponse(BaseModel):
     status_code: int = 200
+    headers: Optional[dict] = None
+    body: Union[dict, BaseModel]
+
+    @property
+    def data(self) -> dict:
+        if isinstance(self.body, BaseModel):
+            return self.body.dict()
+        return self.body
 
 
 class ErrorResponse(BaseModel):
@@ -17,26 +25,26 @@ class ErrorResponse(BaseModel):
         extra = Extra.allow
 
 
-class StartGameResponse(BaseResponse):
-    game_id: int
+class StartGameResponse(BaseModel):
+    game_id: str
     game_state: GameState
 
 
-class GetGameStateResponse(BaseResponse):
+class GetGameStateResponse(BaseModel):
     game_state: GameState
 
 
-class HintResponse(BaseResponse):
+class HintResponse(BaseModel):
     given_hint: GivenHint
     game_state: GameState
 
 
-class GuessResponse(BaseResponse):
+class GuessResponse(BaseModel):
     given_guess: Optional[GivenGuess]
     game_state: GameState
 
 
-class NextMoveResponse(BaseResponse):
+class NextMoveResponse(BaseModel):
     given_hint: Optional[GivenHint] = None
     given_guess: Optional[GivenGuess] = None
     used_solver: Solver
